@@ -1,7 +1,7 @@
 /* Snownews - A lightweight console RSS newsreader
  * $Id: conversions.c 1173 2006-10-14 21:41:42Z kiza $
  * 
- * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de> and
+ * Copyright 2003-2009 Oliver Feiler <kiza@kcore.de> and
  *                     Rene Puls <rpuls@gmx.net>
  *
  * conversions.c
@@ -52,9 +52,12 @@
 #include "setup.h"
 #include "digcalc.h"
 #include "md5.h"
+#include "io-internal.h"
 
 extern struct entity *first_entity;
 
+extern char *forced_target_charset;
+
 int calcAgeInDays (struct tm * t);
 
 #ifdef STATIC_CONST_ICONV
@@ -70,7 +73,7 @@ char * iconvert (char * inbuf) {
 
 	/*(void)strlcpy(target_charset, nl_langinfo(CODESET), sizeof(target_charset));*/
 	strncpy(target_charset, nl_langinfo(CODESET), sizeof(target_charset));
-
+		
 	/* Take a shortcut. */
 	if (strcasecmp (target_charset, "UTF-8") == 0)
 		return strdup(inbuf);
@@ -82,7 +85,11 @@ char * iconvert (char * inbuf) {
 	strncat(target_charset, "//TRANSLIT", sizeof(target_charset));
 
 	/* cd = iconv_open(nl_langinfo(CODESET), "UTF-8"); */
-	cd = iconv_open (target_charset, "UTF-8");
+	if (forced_target_charset) {
+		cd = iconv_open (forced_target_charset, "UTF-8");
+	} else {
+		cd = iconv_open (target_charset, "UTF-8");
+	}
 	if (cd == (iconv_t) -1) {
 		return NULL;
 	}
@@ -561,12 +568,14 @@ void CleanupString (char * string, int tidyness) {
 	
 	len = strlen(string);
 	/* Eat newlines and tabs along the whole string. */
-	if (tidyness == 1) {
-		for (i = 0; i < len; i++) {
-			if ((string[i] == '\t') || (string[i] == '\n'))
-				string[i] = ' ';
+	for (i = 0; i < len; i++) {
+		if (string[i] == '\t') {
+			string[i] = ' ';
 		}
-	}
+		if (tidyness == 1 && string[i] == '\n') {
+			string[i] = ' ';
+		}
+	}	
 }
 
 /* http://foo.bar/address.rdf -> http:__foo.bar_address.rdf */
