@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: netio.c 1173 2006-10-14 21:41:42Z kiza $
+ * $Id: netio.c 1181 2008-07-27 07:27:56Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -296,6 +296,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	char * inflatedbody;
 	int quirksmode = 0;			/* IIS operation mode. */
 	int authfailed = 0;			/* Avoid repeating failed auth requests endlessly. */
+	int gzipstatus = 0;
 
 	
 	if (!suppressoutput) {
@@ -837,8 +838,12 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	/* If inflate==1 we need to decompress the content.. */
 	if (inflate == 1) {
 		/* gzipinflate */
-		if (jg_gzip_uncompress (body, length, (void **)&inflatedbody, &cur_ptr->content_length) != 0) {
+		gzipstatus = jg_gzip_uncompress (body, length, (void **)&inflatedbody, &cur_ptr->content_length);
+		if (gzipstatus != 0) {
+			char errstr[255];
 			free (body);
+			snprintf(errstr, sizeof(errstr), _("zlib exited with code: %d"), gzipstatus);
+			printlog(cur_ptr, errstr);
 			cur_ptr->netio_error = NET_ERR_GZIP_ERR;
 			return NULL;
 		}
